﻿using Prism.Commands;
using Prism.Mvvm;
using SfDataGrid_ComboBoxDemo.Model;
using System;
using System.Collections.ObjectModel;
using System.Linq;
using System.Windows.Input;

namespace SfDataGrid_ComboBoxDemo
{
    public class ViewModel : BindableBase
    {
        public ICommand ShipCountrySelectionChanged
        {
            get => _shipCountrySelectionChanged;
            set
            {
                _shipCountrySelectionChanged = value;
                RaisePropertyChanged(nameof(ShipCountrySelectionChanged));
            }
        }


        private OrderInfo _order;
        public OrderInfo Order
        {
            get
            {
                return _order;
            }
            set
            {
                _order = value;
                RaisePropertyChanged(nameof(Order));
            }
        }

        private ObservableCollection<OrderInfo> _orderList;
        public ObservableCollection<OrderInfo> OrderList
        {
            get
            {
                return _orderList;
            }
            set
            {
                _orderList = value;
                RaisePropertyChanged(nameof(OrderList));
            }
        }
        public ObservableCollection<ShippingLocation> _shipcities;
        public ObservableCollection<ShippingLocation> Shipcities
        {
            get
            {
                return _shipcities;
            }
            set
            {
                _shipcities = value;
                RaisePropertyChanged(nameof(Shipcities));
            }
        }

        public ObservableCollection<string> _shipCountriesStrings = new ObservableCollection<string>();

        private ICommand _shipCountrySelectionChanged;
        private ICommand _countryChangedCommand;
        private ICommand _countryChangedMCDDCommand;

        public ObservableCollection<string> ShipCountriesString
        {
            get
            {
                return _shipCountriesStrings;
            }
            set
            {
                _shipCountriesStrings = value;
                RaisePropertyChanged();
            }
        }

        public ICommand CountryChangedMCDDCommand
        {
            get => _countryChangedMCDDCommand;
            set
            {
                _countryChangedMCDDCommand = value;
                RaisePropertyChanged();
            }
        }
        public ICommand CountryChangedCommand
        {
            get => _countryChangedCommand;
            set
            {
                _countryChangedCommand = value;
                RaisePropertyChanged();
            }
        }
        public ViewModel()
        {
            this.Generate();
            CountryChangedCommand = new DelegateCommand<object>(OnCountryChangedCommand);
            CountryChangedMCDDCommand = new DelegateCommand(OnCountryChangedMCDDCommand);
        }

        private void OnCountryChangedCommand(object obj)
        {
            Console.WriteLine("Inside country changed... !!!");
            //Do something.
        }


        private void OnCountryChangedMCDDCommand()
        {
            Console.WriteLine("Inside country from multicolumn dropdown... !!! "+ SelectedCountryBelow.Country);
        }


        private ShippingLocation selectedCountryBelow;
        public ShippingLocation SelectedCountryBelow
        {
            get { return selectedCountryBelow; }
            set {
                selectedCountryBelow = value;
                RaisePropertyChanged();

            }
        }


        public void Generate()
        {
            var _newshipcities = new ObservableCollection<ShippingLocation>();
            _newshipcities.Add(new ShippingLocation() { ShipId = 1, Country = "Italy", CityName = "Bergamo", RateValue = 10 });
            _newshipcities.Add(new ShippingLocation() { ShipId = 2, Country = "Austria", CityName = "Graz", RateValue = 20 });
            _newshipcities.Add(new ShippingLocation() { ShipId = 3, Country = "Brazil", CityName = "Campinas", RateValue = 30 });
            _newshipcities.Add(new ShippingLocation() { ShipId = 4, Country = "Finland", CityName = "Helsinki", RateValue = 40 });
            _newshipcities.Add(new ShippingLocation() { ShipId = 5, Country = "Denmark", CityName = "Århus", RateValue = 50 });
            _newshipcities.Add(new ShippingLocation() { ShipId = 6, Country = "Ireland", CityName = "Cork", RateValue = 60 });
            _newshipcities.Add(new ShippingLocation() { ShipId = 7, Country = "Canada", CityName = "Montréal", RateValue = 70 });
            _newshipcities.Add(new ShippingLocation() { ShipId = 7, Country = "Canada", CityName = "Quebec", RateValue = 60 });

            Shipcities = _newshipcities;
            ShipCountriesString = new ObservableCollection<string>(_newshipcities.Select(x => x.Country).ToList());

             var _neworderList = new ObservableCollection<OrderInfo>();
            _neworderList.Add(new OrderInfo()
            {
                ProductId = 1001,
                ProductName = "Alice Mutton",
                NoOfOrders = 10,
                OrderDate = new DateTime(2015, 5, 2),
                CountryName = "Austria",
                SelectedShippingLocation = Shipcities.FirstOrDefault(x => x.Country == "Austria"),
                ShipCity = "Graz"
            });
            _neworderList.Add(new OrderInfo()
            {
                ProductId = 1002,
                ProductName = "NuNuCa Nuß-Nougat-Creme",
                NoOfOrders = 10,
                OrderDate = new DateTime(2015, 5, 20),
                CountryName = "Ireland",
                SelectedShippingLocation = Shipcities.FirstOrDefault(x => x.Country == "Ireland"),
                ShipCity = "Cork"
            });
            _neworderList.Add(new OrderInfo()
            {
                ProductId = 1003,
                ProductName = "Boston Crab Meat",
                NoOfOrders = 100,
                OrderDate = new DateTime(2015, 5, 3),
                CountryName = "Finland",
                SelectedShippingLocation = Shipcities.FirstOrDefault(x => x.Country == "Finland"),
                ShipCity = "Helsinki"
            });
            _neworderList.Add(new OrderInfo()
            {
                ProductId = 1004,
                ProductName = "Konbu",
                NoOfOrders = 50,
                OrderDate = new DateTime(2015, 5, 13),
                CountryName = "Denmark",
                SelectedShippingLocation = Shipcities.FirstOrDefault(x => x.Country == "Denmark"),
                ShipCity = "Århus"
            });
            _neworderList.Add(new OrderInfo()
            {
                ProductId = 1005,
                ProductName = "Boston Crab Meat",
                NoOfOrders = 20,
                OrderDate = new DateTime(2015, 5, 23),
                CountryName = "Italy",
                SelectedShippingLocation = Shipcities.FirstOrDefault(x => x.Country == "Italy"),
                ShipCity = "Bergamo"
            });
            _neworderList.Add(new OrderInfo()
            {
                ProductId = 1006,
                ProductName = "Raclette Courdavault",
                NoOfOrders = 20,
                OrderDate = new DateTime(2015, 5, 13),
                CountryName = "Brazil",
                SelectedShippingLocation = Shipcities.FirstOrDefault(x => x.Country == "Brazil"),
                ShipCity = "Campinas"
            });
            _neworderList.Add(new OrderInfo()
            {
                ProductId = 1007,
                ProductName = "Wimmers gute Semmelknödel",
                NoOfOrders = 20,
                OrderDate = new DateTime(2015, 5, 13),
                CountryName = "Canada",
                SelectedShippingLocation = Shipcities.FirstOrDefault(x => x.Country == "Canada"),
                ShipCity = "Montréal"
            });

            OrderList = new ObservableCollection<OrderInfo>(_neworderList);
            selectedCountryBelow = Shipcities.First();
        }

    }
}
